.. image:: https://img.shields.io/pypi/v/vr.runners.svg
   :target: https://pypi.org/project/vr.runners

.. image:: https://img.shields.io/pypi/pyversions/vr.runners.svg

.. image:: https://img.shields.io/pypi/dm/vr.runners.svg

.. image:: https://img.shields.io/travis/yougov/vr.runners/master.svg
   :target: http://travis-ci.org/yougov/vr.runners

``vr.runners`` is a component of the `Velociraptor
<https://github.com/yougov/velociraptor>`_ project.

Runners are used for configuring, invoking, and tearing down
lxc containers.

License
=======

License is indicated in the project metadata (typically one or more
of the Trove classifiers). For more details, see `this explanation
<https://github.com/jaraco/skeleton/issues/1>`_.
